@@ -18,10 +18,18 @@ function _aws_cdk_aws_fms_CfnPolicy(p) {
 }
 function _aws_cdk_aws_fms_CfnPolicy_IEMapProperty(p) {
 }
+function _aws_cdk_aws_fms_CfnPolicy_NetworkFirewallPolicyProperty(p) {
+}
+function _aws_cdk_aws_fms_CfnPolicy_PolicyOptionProperty(p) {
+}
 function _aws_cdk_aws_fms_CfnPolicy_PolicyTagProperty(p) {
 }
 function _aws_cdk_aws_fms_CfnPolicy_ResourceTagProperty(p) {
 }
+function _aws_cdk_aws_fms_CfnPolicy_SecurityServicePolicyDataProperty(p) {
+}
+function _aws_cdk_aws_fms_CfnPolicy_ThirdPartyFirewallPolicyProperty(p) {
+}
 function print(name, deprecationMessage) {
     const deprecated = process.env.JSII_DEPRECATED;
     const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
@@ -58,4 +66,4 @@ class DeprecationError extends Error {
         });
     }
 }
-module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_fms_CfnNotificationChannelProps, _aws_cdk_aws_fms_CfnNotificationChannel, _aws_cdk_aws_fms_CfnPolicyProps, _aws_cdk_aws_fms_CfnPolicy, _aws_cdk_aws_fms_CfnPolicy_IEMapProperty, _aws_cdk_aws_fms_CfnPolicy_PolicyTagProperty, _aws_cdk_aws_fms_CfnPolicy_ResourceTagProperty };
+module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_fms_CfnNotificationChannelProps, _aws_cdk_aws_fms_CfnNotificationChannel, _aws_cdk_aws_fms_CfnPolicyProps, _aws_cdk_aws_fms_CfnPolicy, _aws_cdk_aws_fms_CfnPolicy_IEMapProperty, _aws_cdk_aws_fms_CfnPolicy_NetworkFirewallPolicyProperty, _aws_cdk_aws_fms_CfnPolicy_PolicyOptionProperty, _aws_cdk_aws_fms_CfnPolicy_PolicyTagProperty, _aws_cdk_aws_fms_CfnPolicy_ResourceTagProperty, _aws_cdk_aws_fms_CfnPolicy_SecurityServicePolicyDataProperty, _aws_cdk_aws_fms_CfnPolicy_ThirdPartyFirewallPolicyProperty };
